==> ejc-sddjsorg-api-3.0.0-20211015.112102-15-sources.jar: com/ejianc/business/production/vo/ProductionOrgVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.production.vo.ProductionOrgVO;

/**
 * 产权登记生成的公司信息
 *
 * @author generator
 *
 */
public class ProductionOrgVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String code; // 登记单号
    private java.lang.String name; // 名称
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用代码
    private java.lang.Integer inReacrd; // 是否在集团备案
    private java.lang.Long outCapitalOrg; // 国家出资企业id
    private java.lang.String outCapitalOrgName; // 国家出资企业名称
    private java.lang.Long relationToOutOrg; // 与国家出资企业的关系id
    private java.lang.String relationToOutOrgName; // 与国家出资企业的关系名称
    private java.lang.Integer beOwner; // 是否国家出资企业业主
    private java.lang.Long mainCapitalOrgId; // 主要出资人id
    private java.lang.String mainCapitalOrgName; // 主要出资人名称
    private java.lang.Long registerCountryId; // 注册国家id
    private java.lang.String registerCountryName; // 注册国家名称
    private java.lang.String registerIn; // 注册地境内/境外
    private java.lang.String registerAddress; // 注册地
    private java.util.Date registerDate; // 注册日期
    private java.math.BigDecimal registerCapital; // 注册资本
    private java.lang.Long currencyTypeId; // 注册资本币种id
    private java.lang.String currencyTypeName; // 注册资本币种名称
    private java.lang.String registerCapitalBig; // 注册资本大写
    private java.lang.Long orgTypeId; // 企业类别id
    private java.lang.String orgTypeName; // 企业类别名称
    private java.lang.Long regulatoryBodiesId; // 国资监管机构id
    private java.lang.String regulatoryBodies; // 国资监管机构
    private java.lang.Long orgFormId; // 组织形式
    private java.lang.String orgFormName; // 组织形式
    private java.lang.String majorIndustriesId; // 主要行业
    private java.lang.String majorIndustries; // 主要行业
    private java.lang.String productLevel; // 企业产权级次
    private java.lang.String mangerLevel; // 企业管理级次
    private java.lang.Integer mergeTable; // 是否并表
    private java.lang.Integer beListed; // 是否上市公司
    private java.lang.Integer beClosed; // 是否存在休眠/停业/歇业等情况
    private java.lang.Long productionId; // 产权登记单id


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 统一社会信用代码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 是否在集团备案
     */
    public java.lang.Integer getInReacrd() {
        return inReacrd;
    }

    /**
     * 是否在集团备案
     */
    public void setInReacrd(java.lang.Integer inReacrd) {
        this.inReacrd = inReacrd;
    }
    /**
     * 国家出资企业id
     */
    public java.lang.Long getOutCapitalOrg() {
        return outCapitalOrg;
    }

    /**
     * 国家出资企业id
     */
    public void setOutCapitalOrg(java.lang.Long outCapitalOrg) {
        this.outCapitalOrg = outCapitalOrg;
    }
    /**
     * 国家出资企业名称
     */
    public java.lang.String getOutCapitalOrgName() {
        return outCapitalOrgName;
    }

    /**
     * 国家出资企业名称
     */
    public void setOutCapitalOrgName(java.lang.String outCapitalOrgName) {
        this.outCapitalOrgName = outCapitalOrgName;
    }
    /**
     * 与国家出资企业的关系id
     */
    public java.lang.Long getRelationToOutOrg() {
        return relationToOutOrg;
    }

    /**
     * 与国家出资企业的关系id
     */
    public void setRelationToOutOrg(java.lang.Long relationToOutOrg) {
        this.relationToOutOrg = relationToOutOrg;
    }
    /**
     * 与国家出资企业的关系名称
     */
    public java.lang.String getRelationToOutOrgName() {
        return relationToOutOrgName;
    }

    /**
     * 与国家出资企业的关系名称
     */
    public void setRelationToOutOrgName(java.lang.String relationToOutOrgName) {
        this.relationToOutOrgName = relationToOutOrgName;
    }
    /**
     * 是否国家出资企业业主
     */
    public java.lang.Integer getBeOwner() {
        return beOwner;
    }

    /**
     * 是否国家出资企业业主
     */
    public void setBeOwner(java.lang.Integer beOwner) {
        this.beOwner = beOwner;
    }
    /**
     * 主要出资人id
     */
    public java.lang.Long getMainCapitalOrgId() {
        return mainCapitalOrgId;
    }

    /**
     * 主要出资人id
     */
    public void setMainCapitalOrgId(java.lang.Long mainCapitalOrgId) {
        this.mainCapitalOrgId = mainCapitalOrgId;
    }
    /**
     * 主要出资人名称
     */
    public java.lang.String getMainCapitalOrgName() {
        return mainCapitalOrgName;
    }

    /**
     * 主要出资人名称
     */
    public void setMainCapitalOrgName(java.lang.String mainCapitalOrgName) {
        this.mainCapitalOrgName = mainCapitalOrgName;
    }
    /**
     * 注册国家id
     */
    public java.lang.Long getRegisterCountryId() {
        return registerCountryId;
    }

    /**
     * 注册国家id
     */
    public void setRegisterCountryId(java.lang.Long registerCountryId) {
        this.registerCountryId = registerCountryId;
    }
    /**
     * 注册国家名称
     */
    public java.lang.String getRegisterCountryName() {
        return registerCountryName;
    }

    /**
     * 注册国家名称
     */
    public void setRegisterCountryName(java.lang.String registerCountryName) {
        this.registerCountryName = registerCountryName;
    }
    /**
     * 注册地境内/境外
     */
    public java.lang.String getRegisterIn() {
        return registerIn;
    }

    /**
     * 注册地境内/境外
     */
    public void setRegisterIn(java.lang.String registerIn) {
        this.registerIn = registerIn;
    }
    /**
     * 注册地
     */
    public java.lang.String getRegisterAddress() {
        return registerAddress;
    }

    /**
     * 注册地
     */
    public void setRegisterAddress(java.lang.String registerAddress) {
        this.registerAddress = registerAddress;
    }
    /**
     * 注册日期
     */
    public java.util.Date getRegisterDate() {
        return registerDate;
    }

    /**
     * 注册日期
     */
    public void setRegisterDate(java.util.Date registerDate) {
        this.registerDate = registerDate;
    }
    /**
     * 注册资本
     */
    public java.math.BigDecimal getRegisterCapital() {
        return registerCapital;
    }

    /**
     * 注册资本
     */
    public void setRegisterCapital(java.math.BigDecimal registerCapital) {
        this.registerCapital = registerCapital;
    }
    /**
     * 注册资本币种id
     */
    public java.lang.Long getCurrencyTypeId() {
        return currencyTypeId;
    }

    /**
     * 注册资本币种id
     */
    public void setCurrencyTypeId(java.lang.Long currencyTypeId) {
        this.currencyTypeId = currencyTypeId;
    }
    /**
     * 注册资本币种名称
     */
    public java.lang.String getCurrencyTypeName() {
        return currencyTypeName;
    }

    /**
     * 注册资本币种名称
     */
    public void setCurrencyTypeName(java.lang.String currencyTypeName) {
        this.currencyTypeName = currencyTypeName;
    }
    /**
     * 注册资本大写
     */
    public java.lang.String getRegisterCapitalBig() {
        return registerCapitalBig;
    }

    /**
     * 注册资本大写
     */
    public void setRegisterCapitalBig(java.lang.String registerCapitalBig) {
        this.registerCapitalBig = registerCapitalBig;
    }
    /**
     * 企业类别id
     */
    public java.lang.Long getOrgTypeId() {
        return orgTypeId;
    }

    /**
     * 企业类别id
     */
    public void setOrgTypeId(java.lang.Long orgTypeId) {
        this.orgTypeId = orgTypeId;
    }
    /**
     * 企业类别名称
     */
    public java.lang.String getOrgTypeName() {
        return orgTypeName;
    }

    /**
     * 企业类别名称
     */
    public void setOrgTypeName(java.lang.String orgTypeName) {
        this.orgTypeName = orgTypeName;
    }
    /**
     * 国资监管机构id
     */
    public java.lang.Long getRegulatoryBodiesId() {
        return regulatoryBodiesId;
    }

    /**
     * 国资监管机构id
     */
    public void setRegulatoryBodiesId(java.lang.Long regulatoryBodiesId) {
        this.regulatoryBodiesId = regulatoryBodiesId;
    }
    /**
     * 国资监管机构
     */
    public java.lang.String getRegulatoryBodies() {
        return regulatoryBodies;
    }

    /**
     * 国资监管机构
     */
    public void setRegulatoryBodies(java.lang.String regulatoryBodies) {
        this.regulatoryBodies = regulatoryBodies;
    }
    /**
     * 组织形式
     */
    public java.lang.Long getOrgFormId() {
        return orgFormId;
    }

    /**
     * 组织形式
     */
    public void setOrgFormId(java.lang.Long orgFormId) {
        this.orgFormId = orgFormId;
    }
    /**
     * 组织形式
     */
    public java.lang.String getOrgFormName() {
        return orgFormName;
    }

    /**
     * 组织形式
     */
    public void setOrgFormName(java.lang.String orgFormName) {
        this.orgFormName = orgFormName;
    }
    /**
     * 主要行业
     */
    public java.lang.String getMajorIndustriesId() {
        return majorIndustriesId;
    }

    /**
     * 主要行业
     */
    public void setMajorIndustriesId(java.lang.String majorIndustriesId) {
        this.majorIndustriesId = majorIndustriesId;
    }
    /**
     * 主要行业
     */
    public java.lang.String getMajorIndustries() {
        return majorIndustries;
    }

    /**
     * 主要行业
     */
    public void setMajorIndustries(java.lang.String majorIndustries) {
        this.majorIndustries = majorIndustries;
    }
    /**
     * 企业产权级次
     */
    public java.lang.String getProductLevel() {
        return productLevel;
    }

    /**
     * 企业产权级次
     */
    public void setProductLevel(java.lang.String productLevel) {
        this.productLevel = productLevel;
    }
    /**
     * 企业管理级次
     */
    public java.lang.String getMangerLevel() {
        return mangerLevel;
    }

    /**
     * 企业管理级次
     */
    public void setMangerLevel(java.lang.String mangerLevel) {
        this.mangerLevel = mangerLevel;
    }
    /**
     * 是否并表
     */
    public java.lang.Integer getMergeTable() {
        return mergeTable;
    }

    /**
     * 是否并表
     */
    public void setMergeTable(java.lang.Integer mergeTable) {
        this.mergeTable = mergeTable;
    }
    /**
     * 是否上市公司
     */
    public java.lang.Integer getBeListed() {
        return beListed;
    }

    /**
     * 是否上市公司
     */
    public void setBeListed(java.lang.Integer beListed) {
        this.beListed = beListed;
    }
    /**
     * 是否存在休眠/停业/歇业等情况
     */
    public java.lang.Integer getBeClosed() {
        return beClosed;
    }

    /**
     * 是否存在休眠/停业/歇业等情况
     */
    public void setBeClosed(java.lang.Integer beClosed) {
        this.beClosed = beClosed;
    }
    /**
     * 产权登记单id
     */
    public java.lang.Long getProductionId() {
        return productionId;
    }

    /**
     * 产权登记单id
     */
    public void setProductionId(java.lang.Long productionId) {
        this.productionId = productionId;
    }
}

==> ejc-sddjsorg-api-3.0.0-20211021.075752-43-sources.jar: com/ejianc/business/production/vo/ProductionOrgVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.production.vo.ProductionOrgVO;

/**
 * 产权登记生成的公司信息
 *
 * @author generator
 *
 */
public class ProductionOrgVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.String code; // 登记单号
    private java.lang.String name; // 名称
    private java.lang.String unifiedSocialCreditCode; // 统一社会信用代码
    private java.lang.Integer inReacrd; // 是否在集团备案
    private java.lang.Long outCapitalOrg; // 国家出资企业id
    private java.lang.String outCapitalOrgName; // 国家出资企业名称
    private java.lang.Long relationToOutOrg; // 与国家出资企业的关系id
    private java.lang.String relationToOutOrgName; // 与国家出资企业的关系名称
    private java.lang.Integer beOwner; // 是否国家出资企业业主
    private java.lang.Long mainCapitalOrgId; // 主要出资人id
    private java.lang.String mainCapitalOrgName; // 主要出资人名称
    private java.lang.Long registerCountryId; // 注册国家id
    private java.lang.String registerCountryName; // 注册国家名称
    private java.lang.String registerIn; // 注册地境内/境外
    private java.lang.String registerAddress; // 注册地
    private java.util.Date registerDate; // 注册日期
    private java.math.BigDecimal registerCapital; // 注册资本
    private java.lang.Long currencyTypeId; // 注册资本币种id
    private java.lang.String currencyTypeName; // 注册资本币种名称
    private java.lang.String registerCapitalBig; // 注册资本大写
    private java.lang.Long orgTypeId; // 企业类别id
    private java.lang.String orgTypeName; // 企业类别名称
    private java.lang.Long regulatoryBodiesId; // 国资监管机构id
    private java.lang.String regulatoryBodies; // 国资监管机构
    private java.lang.Long orgFormId; // 组织形式
    private java.lang.String orgFormName; // 组织形式
    private java.lang.Long majorIndustriesId; // 主要行业
    private java.lang.String majorIndustries; // 主要行业
    private java.lang.String productLevel; // 企业产权级次
    private java.lang.String mangerLevel; // 企业管理级次
    private java.lang.Boolean mergeTable; // 是否并表
    private java.lang.Boolean beListed; // 是否上市公司
    private java.lang.Boolean beClosed; // 是否存在休眠/停业/歇业等情况
    private java.lang.Long productionId; // 产权登记单id


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 统一社会信用代码
     */
    public java.lang.String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(java.lang.String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 是否在集团备案
     */
    public java.lang.Integer getInReacrd() {
        return inReacrd;
    }

    /**
     * 是否在集团备案
     */
    public void setInReacrd(java.lang.Integer inReacrd) {
        this.inReacrd = inReacrd;
    }
    /**
     * 国家出资企业id
     */
    public java.lang.Long getOutCapitalOrg() {
        return outCapitalOrg;
    }

    /**
     * 国家出资企业id
     */
    public void setOutCapitalOrg(java.lang.Long outCapitalOrg) {
        this.outCapitalOrg = outCapitalOrg;
    }
    /**
     * 国家出资企业名称
     */
    public java.lang.String getOutCapitalOrgName() {
        return outCapitalOrgName;
    }

    /**
     * 国家出资企业名称
     */
    public void setOutCapitalOrgName(java.lang.String outCapitalOrgName) {
        this.outCapitalOrgName = outCapitalOrgName;
    }
    /**
     * 与国家出资企业的关系id
     */
    public java.lang.Long getRelationToOutOrg() {
        return relationToOutOrg;
    }

    /**
     * 与国家出资企业的关系id
     */
    public void setRelationToOutOrg(java.lang.Long relationToOutOrg) {
        this.relationToOutOrg = relationToOutOrg;
    }
    /**
     * 与国家出资企业的关系名称
     */
    public java.lang.String getRelationToOutOrgName() {
        return relationToOutOrgName;
    }

    /**
     * 与国家出资企业的关系名称
     */
    public void setRelationToOutOrgName(java.lang.String relationToOutOrgName) {
        this.relationToOutOrgName = relationToOutOrgName;
    }
    /**
     * 是否国家出资企业业主
     */
    public java.lang.Integer getBeOwner() {
        return beOwner;
    }

    /**
     * 是否国家出资企业业主
     */
    public void setBeOwner(java.lang.Integer beOwner) {
        this.beOwner = beOwner;
    }
    /**
     * 主要出资人id
     */
    public java.lang.Long getMainCapitalOrgId() {
        return mainCapitalOrgId;
    }

    /**
     * 主要出资人id
     */
    public void setMainCapitalOrgId(java.lang.Long mainCapitalOrgId) {
        this.mainCapitalOrgId = mainCapitalOrgId;
    }
    /**
     * 主要出资人名称
     */
    public java.lang.String getMainCapitalOrgName() {
        return mainCapitalOrgName;
    }

    /**
     * 主要出资人名称
     */
    public void setMainCapitalOrgName(java.lang.String mainCapitalOrgName) {
        this.mainCapitalOrgName = mainCapitalOrgName;
    }
    /**
     * 注册国家id
     */
    public java.lang.Long getRegisterCountryId() {
        return registerCountryId;
    }

    /**
     * 注册国家id
     */
    public void setRegisterCountryId(java.lang.Long registerCountryId) {
        this.registerCountryId = registerCountryId;
    }
    /**
     * 注册国家名称
     */
    public java.lang.String getRegisterCountryName() {
        return registerCountryName;
    }

    /**
     * 注册国家名称
     */
    public void setRegisterCountryName(java.lang.String registerCountryName) {
        this.registerCountryName = registerCountryName;
    }
    /**
     * 注册地境内/境外
     */
    public java.lang.String getRegisterIn() {
        return registerIn;
    }

    /**
     * 注册地境内/境外
     */
    public void setRegisterIn(java.lang.String registerIn) {
        this.registerIn = registerIn;
    }
    /**
     * 注册地
     */
    public java.lang.String getRegisterAddress() {
        return registerAddress;
    }

    /**
     * 注册地
     */
    public void setRegisterAddress(java.lang.String registerAddress) {
        this.registerAddress = registerAddress;
    }
    /**
     * 注册日期
     */
    public java.util.Date getRegisterDate() {
        return registerDate;
    }

    /**
     * 注册日期
     */
    public void setRegisterDate(java.util.Date registerDate) {
        this.registerDate = registerDate;
    }
    /**
     * 注册资本
     */
    public java.math.BigDecimal getRegisterCapital() {
        return registerCapital;
    }

    /**
     * 注册资本
     */
    public void setRegisterCapital(java.math.BigDecimal registerCapital) {
        this.registerCapital = registerCapital;
    }
    /**
     * 注册资本币种id
     */
    public java.lang.Long getCurrencyTypeId() {
        return currencyTypeId;
    }

    /**
     * 注册资本币种id
     */
    public void setCurrencyTypeId(java.lang.Long currencyTypeId) {
        this.currencyTypeId = currencyTypeId;
    }
    /**
     * 注册资本币种名称
     */
    public java.lang.String getCurrencyTypeName() {
        return currencyTypeName;
    }

    /**
     * 注册资本币种名称
     */
    public void setCurrencyTypeName(java.lang.String currencyTypeName) {
        this.currencyTypeName = currencyTypeName;
    }
    /**
     * 注册资本大写
     */
    public java.lang.String getRegisterCapitalBig() {
        return registerCapitalBig;
    }

    /**
     * 注册资本大写
     */
    public void setRegisterCapitalBig(java.lang.String registerCapitalBig) {
        this.registerCapitalBig = registerCapitalBig;
    }
    /**
     * 企业类别id
     */
    public java.lang.Long getOrgTypeId() {
        return orgTypeId;
    }

    /**
     * 企业类别id
     */
    public void setOrgTypeId(java.lang.Long orgTypeId) {
        this.orgTypeId = orgTypeId;
    }
    /**
     * 企业类别名称
     */
    public java.lang.String getOrgTypeName() {
        return orgTypeName;
    }

    /**
     * 企业类别名称
     */
    public void setOrgTypeName(java.lang.String orgTypeName) {
        this.orgTypeName = orgTypeName;
    }
    /**
     * 国资监管机构id
     */
    public java.lang.Long getRegulatoryBodiesId() {
        return regulatoryBodiesId;
    }

    /**
     * 国资监管机构id
     */
    public void setRegulatoryBodiesId(java.lang.Long regulatoryBodiesId) {
        this.regulatoryBodiesId = regulatoryBodiesId;
    }
    /**
     * 国资监管机构
     */
    public java.lang.String getRegulatoryBodies() {
        return regulatoryBodies;
    }

    /**
     * 国资监管机构
     */
    public void setRegulatoryBodies(java.lang.String regulatoryBodies) {
        this.regulatoryBodies = regulatoryBodies;
    }
    /**
     * 组织形式
     */
    public java.lang.Long getOrgFormId() {
        return orgFormId;
    }

    /**
     * 组织形式
     */
    public void setOrgFormId(java.lang.Long orgFormId) {
        this.orgFormId = orgFormId;
    }
    /**
     * 组织形式
     */
    public java.lang.String getOrgFormName() {
        return orgFormName;
    }

    /**
     * 组织形式
     */
    public void setOrgFormName(java.lang.String orgFormName) {
        this.orgFormName = orgFormName;
    }
    /**
     * 主要行业
     */
    public Long getMajorIndustriesId() {
        return majorIndustriesId;
    }

    public void setMajorIndustriesId(Long majorIndustriesId) {
        this.majorIndustriesId = majorIndustriesId;
    }

    /**
     * 主要行业
     */
    public java.lang.String getMajorIndustries() {
        return majorIndustries;
    }

    /**
     * 主要行业
     */
    public void setMajorIndustries(java.lang.String majorIndustries) {
        this.majorIndustries = majorIndustries;
    }
    /**
     * 企业产权级次
     */
    public java.lang.String getProductLevel() {
        return productLevel;
    }

    /**
     * 企业产权级次
     */
    public void setProductLevel(java.lang.String productLevel) {
        this.productLevel = productLevel;
    }
    /**
     * 企业管理级次
     */
    public java.lang.String getMangerLevel() {
        return mangerLevel;
    }

    /**
     * 企业管理级次
     */
    public void setMangerLevel(java.lang.String mangerLevel) {
        this.mangerLevel = mangerLevel;
    }
    /**
     * 是否并表
     */


    public void setMergeTable(Boolean mergeTable) {
        this.mergeTable = mergeTable;
    }

    public Boolean getBeListed() {
        return beListed;
    }

    public void setBeListed(Boolean beListed) {
        this.beListed = beListed;
    }

    public Boolean getBeClosed() {
        return beClosed;
    }

    public void setBeClosed(Boolean beClosed) {
        this.beClosed = beClosed;
    }

    /**
     * 产权登记单id
     */
    public java.lang.Long getProductionId() {
        return productionId;
    }

    /**
     * 产权登记单id
     */
    public void setProductionId(java.lang.Long productionId) {
        this.productionId = productionId;
    }
}
